set linesize 32000
set pagesize 1000
set long 2000000000
set longchunksize 1000
set head off;
set verify off;
set termout off;
 
column u new_value us noprint;
column n new_value ns noprint;
 
select name n from v$database;
select user u from dual;
set sqlprompt &ns:&us>

set head on
set echo on
set termout on
set trimspool on

set timing on

spool &ns.cpuandwaits3.log

set define off

drop table busy_time;

create table busy_time as 
select before.snap_id,
(after.value-before.value) busy_time
from 
DBA_HIST_OSSTAT before,
DBA_HIST_OSSTAT after
where 
before.STAT_NAME='BUSY_TIME' and
before.STAT_NAME=after.STAT_NAME and
before.snap_id+1=after.snap_id;


drop table idle_time;

create table idle_time as 
select before.snap_id,
(after.value-before.value) idle_time
from 
DBA_HIST_OSSTAT before,
DBA_HIST_OSSTAT after
where 
before.STAT_NAME='IDLE_TIME' and
before.STAT_NAME=after.STAT_NAME and
before.snap_id+1=after.snap_id;

drop table busy_percent;

create table busy_percent as
select 
b.snap_id,
(100*b.busy_time)/(b.busy_time+i.idle_time) busy_percent
from
busy_time b,
idle_time i
where
b.snap_id=i.snap_id;

drop table lfs_waits;

create table lfs_waits as
select
before.snap_id,
(after.total_waits-before.total_waits) num_waits,
(after.time_waited_micro-before.time_waited_micro)/(after.total_waits-before.total_waits) avg_micro
from DBA_HIST_SYSTEM_EVENT before, DBA_HIST_SYSTEM_EVENT after
where 
before.event_name='log file sync' and
after.event_name=before.event_name and
after.snap_id=before.snap_id+1 and
(after.total_waits-before.total_waits) > 0;

drop table lfpw_waits;

create table lfpw_waits as
select
before.snap_id,
(after.total_waits-before.total_waits) num_waits,
(after.time_waited_micro-before.time_waited_micro)/(after.total_waits-before.total_waits) avg_micro
from DBA_HIST_SYSTEM_EVENT before, DBA_HIST_SYSTEM_EVENT after
where 
before.event_name='log file parallel write' and
after.event_name=before.event_name and
after.snap_id=before.snap_id+1 and
(after.total_waits-before.total_waits) > 0;

column END_INTERVAL_TIME format a26

select 
sn.END_INTERVAL_TIME,
b.busy_percent cpu_pct_busy,
s.avg_micro/1000 avg_commit_ms,
w.avg_micro/1000 avg_write_ms
from 
busy_percent b,
lfs_waits s,
lfpw_waits w,
DBA_HIST_SNAPSHOT sn
where
b.snap_id=s.snap_id and
s.snap_id=w.snap_id and
s.num_waits > 1000000 and
b.snap_id=sn.snap_id
order by b.snap_id;


spool off
